S2ChoiceConfig class

Choices configuration

Mixed-in types
Annotations

Constructors

S2ChoiceConfig({S2ChoiceType? type, S2ChoiceLayout layout = S2ChoiceLayout.list, Axis direction = Axis.vertical, double? spacing, double? runSpacing, EdgeInsetsGeometry? padding, SliverGridDelegate? gridDelegate, int gridCount = 2, double gridSpacing = 0, bool useDivider = false, Color? dividerColor, double? dividerSpacing, double? dividerThickness, Color? overscrollColor, S2ChoiceStyle? style, S2ChoiceStyle? activeStyle, ScrollPhysics physics = const ScrollPhysics(), int? pageLimit, Duration? delay})
Create choices configuration
const

Properties

activeStyle → S2ChoiceStyle?
Configure selected choices item style
final
delay → Duration?
Time delay before display the choices
final
direction → Axis
Choice list scroll direction
final
dividerColor → Color?
The divider color
final
dividerSpacing → double?
Spacing between divider widget and choice widget
final
dividerThickness → double?
The divider thickness
final
gridCount → int
The number of children in the cross axis.
final
gridDelegate → SliverGridDelegate?
Controls the layout of tiles in a grid.
final
gridSpacing → double
Fill the crossAxisSpacing and crossAxisSpacing with single configuration
final
hashCode → int
The hash code for this object.
no setterinherited
isGridLayout → bool
Whether the layout is S2ChoiceLayout.grid or type is S2ChoiceType.cards
no setter
isListLayout → bool
Whether the layout is S2ChoiceLayout.list
no setter
isWrapLayout → bool
Whether the layout is S2ChoiceLayout.wrap or type is S2ChoiceType.chips
no setter
layout → S2ChoiceLayout
Choice list layout
final
overscrollColor → Color?
Custom color of the glowing indicator when overscroll the choices list
final
padding → EdgeInsetsGeometry?
Choices wrapper padding
final
pageLimit → int?
limit per page to display the choices
final
physics → ScrollPhysics
Determines the physics of choices list widget
final
runSpacing → double?
How much space to place between the runs themselves in the cross axis.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double?
How much space to place between children in a run in the main axis.
final
style → S2ChoiceStyle?
Configure unselected choices item style
final
type → S2ChoiceType?
Choice item widget type
final
useDivider → bool
Whether the choices item use divider or not
final

Methods

copyWith({S2ChoiceType? type, S2ChoiceLayout? layout, Axis? direction, double? spacing, double? runSpacing, EdgeInsetsGeometry? padding, SliverGridDelegate? gridDelegate, int? gridCount, double? gridSpacing, bool? useDivider, Color? dividerColor, double? dividerSpacing, double? dividerThickness, Color? overscrollColor, S2ChoiceStyle? style, S2ChoiceStyle? activeStyle, ScrollPhysics? physics, int? pageLimit, Duration? delay}) → S2ChoiceConfig
Creates a copy of this S2ChoiceConfig but with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
merge(S2ChoiceConfig? other) → S2ChoiceConfig
Creates a copy of this S2ChoiceConfig but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited