S2ChoiceStyle class

Configure choices item style

Mixed-in types
Annotations

Constructors

S2ChoiceStyle({TextStyle? titleStyle, TextStyle? subtitleStyle, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, double? spacing, bool? showCheckmark, Color? color, Color? accentColor, Color? highlightColor, S2ChoiceControl? control, Clip? clipBehavior, bool? outlined, bool? raised, double? opacity, double? elevation, ShapeBorder? shape})
Create a configuration of choices item style
const

Properties

accentColor → Color?
Secondary color of unselected choice item
final
clipBehavior → Clip?
Shape clip behavior
final
color → Color?
Primary color of unselected choice item
final
control → S2ChoiceControl?
Where to place the control in widgets that use ListTile to position a control next to a label.
final
elevation → double?
If raised is true, define the elevation of the raised chip widget
final
hashCode → int
The hash code for this object.
no setterinherited
highlightColor → Color?
Highlighted text color
final
margin → EdgeInsetsGeometry?
Choices item margin
final
opacity → double?
If outlined is true this value becomes the border opacity, defaults to 0.3
final
outlined → bool?
Whether the chip is outlined or not
final
padding → EdgeInsetsGeometry?
Choices item padding
final
raised → bool?
Whether the chip is raised or not
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
Shape of the chip widget
final
showCheckmark → bool?
Whether the chips use checkmark or not
final
spacing → double?
Spacing between the avatar/secondary widget and the text widget when S2ChoiceConfig.type is S2ChoiceType.cards
final
subtitleStyle → TextStyle?
choices item subtitle style
final
titleStyle → TextStyle?
choices item title style
final

Methods

copyWith({TextStyle? titleStyle, TextStyle? subtitleStyle, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, double? spacing, bool? showCheckmark, S2ChoiceControl? control, Color? highlightColor, Color? color, Color? accentColor, Clip? clipBehavior, bool? outlined, bool? raised, double? opacity, double? elevation, ShapeBorder? shape}) → S2ChoiceStyle
Creates a copy of this S2ChoiceStyle but with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
merge(S2ChoiceStyle? other) → S2ChoiceStyle
Returns a new S2ChoiceStyle that is a combination of this object and the given other style.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited