S2GroupConfig class

Choices configuration

Mixed-in types
Annotations

Constructors

S2GroupConfig({bool enabled = false, bool useSelector = false, bool useCounter = true, S2GroupSort? sortBy, S2GroupHeaderStyle headerStyle = const S2GroupHeaderStyle()})
Create choices configuration
const

Properties

disabled → bool
Opposite value of enabled
no setter
enabled → bool
Whether the choices list is grouped or not, based on S2Choice.group
final
hashCode → int
The hash code for this object.
no setterinherited
headerStyle → S2GroupHeaderStyle
Configure choices group header theme
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortBy → S2GroupSort?
If enabled is true, comparator function to sort the group keys
final
useCounter → bool
If enabled is true, whether the group header displays the choices counter or not
final
useSelector → bool
If enabled is true, whether the group header displays the choices selector toggle or not,
final

Methods

copyWith({bool? enabled, bool? useSelector, bool? useCounter, S2GroupSort? sortBy, S2GroupHeaderStyle? headerStyle}) → S2GroupConfig
Creates a copy of this S2GroupConfig but with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
merge(S2GroupConfig? other) → S2GroupConfig
Returns a new S2GroupConfig that is a combination of this object and the given other style.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited