S2GroupHeaderStyle class

Configure choices group header style

Mixed-in types
Annotations

Constructors

S2GroupHeaderStyle({Color? highlightColor, Color? backgroundColor, TextStyle? textStyle, EdgeInsetsGeometry? padding, double height = 45.0, CrossAxisAlignment? crossAxisAlignment, MainAxisAlignment? mainAxisAlignment})
Create a configuration of choices group header style
const

Properties

backgroundColor → Color?
Group header background color
final
crossAxisAlignment → CrossAxisAlignment?
Group header cross axis alignment
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
Group header height
final
highlightColor → Color?
Highlight color
final
mainAxisAlignment → MainAxisAlignment?
Group header main axis alignment
final
padding → EdgeInsetsGeometry?
Group header padding
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
Group header text style
final

Methods

copyWith({Color? backgroundColor, Color? highlightColor, TextStyle? textStyle, EdgeInsetsGeometry? padding, double? height, CrossAxisAlignment? crossAxisAlignment, MainAxisAlignment? mainAxisAlignment}) → S2GroupHeaderStyle
Creates a copy of this S2GroupHeaderStyle but with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
merge(S2GroupHeaderStyle? other) → S2GroupHeaderStyle
Returns a new S2GroupHeaderStyle that is a combination of this object and the given other style.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited