S2ModalHeaderStyle class

Configure modal option header style

Mixed-in types
Annotations

Constructors

S2ModalHeaderStyle({ShapeBorder? shape, double elevation = 0.5, bool? useLeading, bool centerTitle = false, TextStyle? textStyle, TextStyle? errorStyle, IconThemeData? iconTheme, IconThemeData? actionsIconTheme, Color? backgroundColor, Brightness? brightness})
Create a configuration of modal option header style
const

Properties

actionsIconTheme → IconThemeData?
Header actions icon theme
final
backgroundColor → Color?
Header background color
final
brightness → Brightness?
Header brightness
final
centerTitle → bool
Whether the header title is centered
final
elevation → double
Header elevation
final
errorStyle → TextStyle?
Error text style
final
hashCode → int
The hash code for this object.
no setterinherited
iconTheme → IconThemeData?
Header icon theme
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
Header border shape
final
textStyle → TextStyle?
Header text style used by title and search field
final
useLeading → bool?
Whether the automaticallyImplyLeading is true or false
final

Methods

copyWith({ShapeBorder? shape, double? elevation, Color? backgroundColor, Brightness? brightness, bool? useLeading, bool? centerTitle, TextStyle? textStyle, TextStyle? errorStyle, IconThemeData? iconTheme, IconThemeData? actionsIconTheme}) → S2ModalHeaderStyle
Creates a copy of this S2ModalHeaderStyle but with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
merge(S2ModalHeaderStyle? other) → S2ModalHeaderStyle
Returns a new S2ModalHeaderStyle that is a combination of this object and the given other style.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited