S2ModalStyle class

Configure modal style

Mixed-in types
Annotations

Constructors

S2ModalStyle({ShapeBorder? shape, double? elevation, Color? backgroundColor, Clip? clipBehavior})
Create a configuration of modal style
const

Properties

backgroundColor → Color?
Modal background color
final
clipBehavior → Clip?
Modal clip behavior
final
elevation → double?
Modal elevation used in popup dialog and bottom sheet
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
Modal border shape used in popup dialog and bottom sheet
final

Methods

copyWith({ShapeBorder? shape, double? elevation, Color? backgroundColor, Clip? clipBehavior}) → S2ModalStyle
Creates a copy of this S2ModalStyle but with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
merge(S2ModalStyle? other) → S2ModalStyle
Returns a new S2ModalStyle that is a combination of this object and the given other style.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited