S2MultiSelected<T> class

Inheritance
Mixed-in types

Constructors

S2MultiSelected({List<T> value = const [], List<S2Choice<T>>? choice, S2MultiSelectedResolver<T>? resolver, S2Validation<S2MultiChosen<T>>? validation, String? placeholder})
Default Constructor

Properties

choice ↔ List<S2Choice<T>>?
return an array of the selected S2Choice
covariantgetter/setter pairoverride
error ↔ String
Validation error message
getter/setter pairinherited
group → List<String>?
Returns an array of group of the choice
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isEmpty → bool
Returns true if there are no values in the chosen data
no setterinherited
isNotEmpty → bool
Returns true if there is at least one value in the chosen data
no setterinherited
isNotResolved → bool
Returns true if one of choice or value is null
no setterinherited
isNotValid → bool
Returns true when the selection is not valid
no setterinherited
isResolved → bool
Returns true if choice is not null
no setterinherited
isResolving ↔ bool
Returns true when choice is resolving in the background
getter/setter pairinherited
isValid → bool
Returns true when the selection is valid
no setterinherited
length → int
Returns the length of the choice
no setterinherited
placeholder ↔ String?
A String to return in toString if the title is empty
finalgetter/setter pairinherited-setteroverride-getter
resolver ↔ S2MultiSelectedResolver<T>?
Function to resolve choice from value
covariantgetter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → List<String>?
Returns an array of subtitle of the choice
no setterinherited
title → List<String>?
Returns an array of title of the choice
no setterinherited
validation ↔ S2Validation<S2MultiChosen<T>>?
A function used to validate the selection
covariantfinalgetter/setter pairinherited-setteroverride-getter
value ↔ List<T>
return an array of value of the selected choice
covariantgetter/setter pairoverride

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
has(S2Choice<T> choice) → bool
Returns true if the chosen contains the supplied choice item
inherited
hasAll(List<S2Choice<T>> choices) → bool
Returns `true if the selection has every of the supplied values
inherited
hasAny(List<S2Choice<T>> choices) → bool
Returns true if the selection has any of the supplied values
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
override
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resolve({S2MultiSelectedResolver<T>? defaultResolver}) → void
Resolve choice from value using user defined resolver, or fallback to defaultResolver if resolver is not defined
override
toString() → String
A string representation of this object.
override
toWidget() → Widget
Return a Text widget from toString
inherited
validate() → void
Validate the selection
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited