S2MultiSelection<T> class

Inheritance
Mixed-in types

Constructors

S2MultiSelection({required List<S2Choice<T>>? initial, S2Validation<S2MultiChosen<T>>? validation})
Default constructor

Properties

choice ↔ List<S2Choice<T>>
Returns the choice item(s)
covariantgetter/setter pairoverride
error ↔ String
Validation error message
getter/setter pairinherited
group → List<String>?
Returns an array of group of the choice
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
initial ↔ List<S2Choice<T>>
The Initial selection
covariantfinalgetter/setter pairinherited-setteroverride-getter
isEmpty → bool
Returns true if there are no values in the chosen data
no setterinherited
isNotEmpty → bool
Returns true if there is at least one value in the chosen data
no setterinherited
isNotValid → bool
Returns true when the selection is not valid
no setterinherited
isValid → bool
Returns true when the selection is valid
no setterinherited
length → int
Returns the length of the choice
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → List<String>?
Returns an array of subtitle of the choice
no setterinherited
title → List<String>?
Returns an array of title of the choice
no setterinherited
validation ↔ S2Validation<S2MultiChosen<T>>?
A function used to validate the selection
covariantfinalgetter/setter pairinherited-setteroverride-getter
value → List<T>?
Returns an array of value of the current choice
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clear() → void
Removes all choice(s) from the selection
override
dispose() → void
Discards any resources used by the object.
inherited
has(S2Choice<T> choice) → bool
Returns true if the chosen contains the supplied choice item
inherited
hasAll(List<S2Choice<T>> choices) → bool
Returns `true if the selection has every of the supplied values
inherited
hasAny(List<S2Choice<T>> choices) → bool
Returns true if the selection has any of the supplied values
inherited
merge(List<S2Choice<T>> choices) → void
Add every value in supplied values into the selection
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
override
notifyListeners() → void
Call all the registered listeners.
inherited
omit(List<S2Choice<T>>? choices) → void
Removes every value in supplied values from the selection
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
Reset the current selection to the initial selection
override
select(S2Choice<T> choice, {bool selected = true}) → void
Select or unselect a choice
override
toggle(List<S2Choice<T>> choices, {bool? pull}) → void
Toggle put/pull the supplied values from the selection
toString() → String
A string representation of this object.
override
toWidget() → Widget
Return a Text widget from toString
inherited
validate() → void
Validate the selection
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited