S2SingleState<T> class

State for Single Choice

Inheritance

Constructors

S2SingleState()

Properties

builder → S2SingleBuilder<T>?
Returns the builders collection
no setteroverride
choiceActiveStyle → S2ChoiceStyle?
Returns the active choice style
no setterinherited
choiceConfig → S2ChoiceConfig
Returns the choice config
no setterinherited
choiceEmpty → Widget
Returns the choice empty widget
no setterinherited
choiceList → Widget
Returns the choice items widget
no setterinherited
choiceListBuilder → S2ChoiceListBuilder<T>
Returns the choice item builder by it's current state
no setterinherited
choiceProgress → Widget
Returns the indicator widget indicates the choices is processing
no setterinherited
choiceResolver → S2ChoiceResolver<T>
Returns the default choice builder by its type
no setterinherited
choices ↔ S2Choices<T>?
State of the choice items
getter/setter pairinherited
choiceSelectorAll → Widget?
Returns the choices selector widget
no setteroverride
choiceStyle → S2ChoiceStyle?
Returns the choice style
no setterinherited
confirmButton → Widget
Returns the confirm button widget
no setterinherited
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
customChoiceEmpty → Widget?
Returns the custom empty choice widget
no setteroverride
customConfirmButton → Widget?
Returns the custom confirm button widget
no setteroverride
customModal → Widget?
Returns the custom modal widget
no setteroverride
customModalActions → List<Widget>?
Returns the custom modal actions widgets
no setteroverride
customModalFilter → Widget?
Returns the custom modal filter widget
no setteroverride
customModalFilterToggle → Widget?
Returns the custom widget to show/hide modal filter
no setteroverride
customModalHeader → Widget?
Returns the custom modal header
no setteroverride
debouncer → Debouncer
Debouncer used in search text on changed
finalinherited
defaultActiveChoiceStyle → S2ChoiceStyle
Returns the default style for selected choice
no setterinherited
defaultChoiceEmpty → Widget
Returns the default choice empty widget
no setterinherited
defaultChoiceStyle → S2ChoiceStyle
Returns the default style for unselected choice
no setterinherited
defaultConfirmButton → Widget
Returns the default confirm button widget
no setterinherited
defaultModal → Widget
Returns the default modal widget
no setterinherited
defaultModalActions → List<Widget>
Returns the default modal actions widgets
no setterinherited
defaultModalFilter → Widget
Returns the default modal filter widget
no setterinherited
defaultModalFilterToggle → Widget
Returns the default widget to show/hide modal filter
no setterinherited
defaultModalHeader → Widget
Returns the default modal header widget
no setterinherited
defaultTile → Widget
Returns the default trigger tile widget
no setterinherited
filter ↔ S2Filter?
State of the filter operation
getter/setter pairinherited
groupConfig → S2GroupConfig
Returns the group config
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isMultiChoice → bool
Returns true if the widget is multiple choice
no setterinherited
isSingleChoice → bool
Returns true if the widget is single choice
no setterinherited
Returns the modal widget
no setterinherited
modalActions → List<Widget>
Returns the modal action widgets
no setterinherited
modalBody → Widget
Returns the modal body widget
no setterinherited
modalConfig → S2ModalConfig
Returns the modal config
no setterinherited
modalContext ↔ BuildContext
Context of the modal
getter/setter pairinherited
modalDivider → Widget?
Returns the modal divider widget
no setteroverride
modalError → Widget
Returns the modal error widget
no setterinherited
modalErrorController ↔ S2TextErrorController
getter/setter pairinherited
modalFilter → Widget
Returns the modal filter widget
no setterinherited
modalFilterToggle → Widget?
Returns the widget to show/hide modal filter
no setterinherited
modalFooter → Widget?
Returns the modal footer widget
no setteroverride
modalHeader → Widget?
Returns the modal header widget
no setterinherited
modalHeaderStyle → S2ModalHeaderStyle
Returns the modal header style
no setterinherited
modalSetState ↔ StateSetter?
State setter of the modal
getter/setter pairinherited
modalStyle → S2ModalStyle
Returns the modal style
no setterinherited
modalTitle → Widget
Returns the modal title widget
no setterinherited
modalValidation → S2Validation<S2SingleChosen<T>>?
Returns the validation function to validate the selection made in the modal, if null fallback to validation
no setteroverride
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → S2SingleSelected<T>
State of the selected choice(s)
no setteroverride
selection ↔ S2SingleSelection<T>?
State of the selected choice(s) State of choice(s) selection in the modal
covariantgetter/setter pairoverride
theme → ThemeData
Returns ThemeData from the widget context
no setterinherited
title → String?
Returns the text used as title in trigger tile
no setterinherited
titleWidget → Widget
Returns title in Text widget
no setterinherited
validation → S2Validation<S2SingleChosen<T>>?
Returns the validation function to validate the selected choice
no setteroverride
widget → SmartSelect<T>
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
choiceBuilder(S2Choice<T> choice) → Widget?
Returns the choice item builder from resolver by it's type
override
choiceSecondary(S2Choice<T> choice) → Widget?
Returns the secondary/avatar widget
override
choiceSelector(List<S2Choice<T>>? values) → Widget?
Function to create toggle selector checkbox widget
override
choiceSubtitle(S2Choice<T> choice) → Widget?
Returns the choice subtitle widget
override
choiceTitle(S2Choice<T> choice) → Widget?
Returns the choice title widget
override
closeModal({bool confirmed = true}) → void
Function to close the choice modal
inherited
customGroup(S2Group<T> group) → Widget?
Returns the custom grouped choices widget
override
customGroupHeader(S2Group<T> group) → Widget?
Returns the custom group header widget
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
defaultChoiceSubtitle(S2Choice<T> choice) → Widget
Returns the default choice subtitle widget
inherited
defaultChoiceTitle(S2Choice<T> choice) → Widget
Returns the default choice title widget
inherited
defaultGroup(S2Group<T> group) → Widget
Returns the default grouped choices widget
inherited
defaultGroupHeader(S2Group<T> group) → Widget
Returns the default group header widget
inherited
defaultModalWillClose() → Future<bool>
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant SmartSelect<T> oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
inherited
groupChoices(S2Group<T> group) → Widget
Returns the group choices widget
inherited
groupCounter(S2Group<T> group) → Widget
Returns the group counter widget
inherited
groupedChoices(List<S2Group<T>> groups) → Widget
Returns the grouped choice items widget
inherited
groupHeader(S2Group<T> group) → Widget
Returns the group header widget
inherited
initializeFilter() → void
Function to initialize filter
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
modalErrorShake() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange() → void
Called when the modal closed and selection has confirmed
override
onModalClose(bool confirmed) → void
Called when modal closed
override
onModalOpen() → void
Called when modal opened
override
onModalWillClose() → Future<bool>
Called when modal closed
override
onModalWillOpen() → Future<bool>?
Called when modal opened
override
onSelect(S2Choice<T> choice) → void
Called when selection has made
override
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
resolveChoices() → void
Function to resolve the choices
inherited
resolveSelected() → void
Initiate the selected choice
override
resolveSelection() → void
Function to resolve the selected
override
selectedHandler() → void
The selected listener handler
inherited
selectionHandler() → void
The selection listener handler
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showModal() → void
Function to show the choice modal
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
ungroupedChoices(List<S2Choice<T>>? choiceList) → Widget
Returns the ungrouped choice items widget
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited