S2State<T> class abstract

Smart Select State

Inheritance
Implementers

Constructors

S2State()

Properties

builder → dynamic
Returns the builders collection
no setter
choiceActiveStyle → S2ChoiceStyle?
Returns the active choice style
no setter
choiceConfig → S2ChoiceConfig
Returns the choice config
no setter
choiceEmpty → Widget
Returns the choice empty widget
no setter
choiceList → Widget
Returns the choice items widget
no setter
choiceListBuilder → S2ChoiceListBuilder<T>
Returns the choice item builder by it's current state
no setter
choiceProgress → Widget
Returns the indicator widget indicates the choices is processing
no setter
choiceResolver → S2ChoiceResolver<T>
Returns the default choice builder by its type
no setter
choices ↔ S2Choices<T>?
State of the choice items
getter/setter pair
choiceSelectorAll → Widget?
Returns the choices selector widget
no setter
choiceStyle → S2ChoiceStyle?
Returns the choice style
no setter
confirmButton → Widget
Returns the confirm button widget
no setter
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
customChoiceEmpty → Widget?
Returns the custom empty choice widget
no setter
customConfirmButton → Widget?
Returns the custom confirm button widget
no setter
customModal → Widget?
Returns the custom modal widget
no setter
customModalActions → List<Widget>?
Returns the custom modal actions widgets
no setter
customModalFilter → Widget?
Returns the custom modal filter widget
no setter
customModalFilterToggle → Widget?
Returns the custom widget to show/hide modal filter
no setter
customModalHeader → Widget?
Returns the custom modal header
no setter
debouncer → Debouncer
Debouncer used in search text on changed
final
defaultActiveChoiceStyle → S2ChoiceStyle
Returns the default style for selected choice
no setter
defaultChoiceEmpty → Widget
Returns the default choice empty widget
no setter
defaultChoiceStyle → S2ChoiceStyle
Returns the default style for unselected choice
no setter
defaultConfirmButton → Widget
Returns the default confirm button widget
no setter
defaultModal → Widget
Returns the default modal widget
no setter
defaultModalActions → List<Widget>
Returns the default modal actions widgets
no setter
defaultModalFilter → Widget
Returns the default modal filter widget
no setter
defaultModalFilterToggle → Widget
Returns the default widget to show/hide modal filter
no setter
defaultModalHeader → Widget
Returns the default modal header widget
no setter
defaultTile → Widget
Returns the default trigger tile widget
no setter
filter ↔ S2Filter?
State of the filter operation
getter/setter pair
groupConfig → S2GroupConfig
Returns the group config
no setter
hashCode → int
The hash code for this object.
no setterinherited
isMultiChoice → bool
Returns true if the widget is multiple choice
no setter
isSingleChoice → bool
Returns true if the widget is single choice
no setter
Returns the modal widget
no setter
modalActions → List<Widget>
Returns the modal action widgets
no setter
modalBody → Widget
Returns the modal body widget
no setter
modalConfig → S2ModalConfig
Returns the modal config
no setter
modalContext ↔ BuildContext
Context of the modal
getter/setter pair
modalDivider → Widget?
Returns the modal divider widget
no setter
modalError → Widget
Returns the modal error widget
no setter
modalErrorController ↔ S2TextErrorController
getter/setter pair
modalFilter → Widget
Returns the modal filter widget
no setter
modalFilterToggle → Widget?
Returns the widget to show/hide modal filter
no setter
modalFooter → Widget?
Returns the modal footer widget
no setter
modalHeader → Widget?
Returns the modal header widget
no setter
modalHeaderStyle → S2ModalHeaderStyle
Returns the modal header style
no setter
modalSetState ↔ StateSetter?
State setter of the modal
getter/setter pair
modalStyle → S2ModalStyle
Returns the modal style
no setter
modalTitle → Widget
Returns the modal title widget
no setter
modalValidation → dynamic
Returns the validation function to validate the selection made in the modal, if null fallback to validation
no setter
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → S2Selected<T>
State of the selected choice(s)
no setter
selection ↔ S2Selection<T>?
State of choice(s) selection in the modal
covariantgetter/setter pair
theme → ThemeData
Returns ThemeData from the widget context
no setter
title → String?
Returns the text used as title in trigger tile
no setter
titleWidget → Widget
Returns title in Text widget
no setter
validation → dynamic
Returns the validation function to validate the selected choice
no setter
widget → SmartSelect<T>
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
choiceBuilder(S2Choice<T> choice) → Widget?
Returns the choice item builder from resolver by it's type
choiceSecondary(S2Choice<T> choice) → Widget?
Returns the secondary/avatar widget
choiceSelector(List<S2Choice<T>>? values) → Widget?
Function to create toggle selector checkbox widget
choiceSubtitle(S2Choice<T> choice) → Widget?
Returns the choice subtitle widget
choiceTitle(S2Choice<T> choice) → Widget?
Returns the choice title widget
closeModal({bool confirmed = true}) → void
Function to close the choice modal
customGroup(S2Group<T> group) → Widget?
Returns the custom grouped choices widget
customGroupHeader(S2Group<T> group) → Widget?
Returns the custom group header widget
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
defaultChoiceSubtitle(S2Choice<T> choice) → Widget
Returns the default choice subtitle widget
defaultChoiceTitle(S2Choice<T> choice) → Widget
Returns the default choice title widget
defaultGroup(S2Group<T> group) → Widget
Returns the default grouped choices widget
defaultGroupHeader(S2Group<T> group) → Widget
Returns the default group header widget
defaultModalWillClose() → Future<bool>
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant SmartSelect<T> oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
groupChoices(S2Group<T> group) → Widget
Returns the group choices widget
groupCounter(S2Group<T> group) → Widget
Returns the group counter widget
groupedChoices(List<S2Group<T>> groups) → Widget
Returns the grouped choice items widget
groupHeader(S2Group<T> group) → Widget
Returns the group header widget
initializeFilter() → void
Function to initialize filter
initState() → void
Called when this object is inserted into the tree.
override
modalErrorShake() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange() → void
Called when the modal closed and selection has confirmed
onModalClose(bool confirmed) → void
Called when modal closed
onModalOpen() → void
Called when modal opened
onModalWillClose() → Future<bool>
Called when modal closed
onModalWillOpen() → Future<bool>?
Called when modal opened
onSelect(S2Choice<T> choice) → void
Called when selection has made
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
resolveChoices() → void
Function to resolve the choices
resolveSelected() → void
Initiate the selected choice
resolveSelection() → void
Function to resolve the selected
selectedHandler() → void
The selected listener handler
selectionHandler() → void
The selection listener handler
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
override
showModal() → void
Function to show the choice modal
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
ungroupedChoices(List<S2Choice<T>>? choiceList) → Widget
Returns the ungrouped choice items widget

Operators

operator ==(Object other) → bool
The equality operator.
inherited