S2Tile<T> class

Default trigger/tile widget

Inheritance

Constructors

S2Tile({Key? key, required Widget value, required GestureTapCallback onTap, required Widget title, Widget? leading, Widget? trailing, String? loadingText, Widget? loadingMessage, Widget? loadingIndicator, bool isLoading = false, bool isError = false, bool isTwoLine = false, bool enabled = true, bool selected = false, bool dense = false, bool hideValue = false, EdgeInsetsGeometry? padding, Widget? body})
Create a default trigger widget
const
S2Tile.fromState(S2State<T> state, {Key? key, Widget? value, GestureTapCallback? onTap, Widget? title, bool? isError, bool? isLoading, Widget? leading, Widget? trailing, String? loadingText, Widget? loadingMessage, Widget? loadingIndicator, bool isTwoLine = false, bool enabled = true, bool selected = false, bool dense = false, bool hideValue = false, EdgeInsetsGeometry? padding, Widget? body})
Create a default trigger widget from state

Properties

body → Widget?
widget to display below the tile usually used to display chips with S2TileChips
final
dense → bool
Whether this list tile is part of a vertically dense list.
final
enabled → bool
Whether this list tile is interactive.
final
hashCode → int
The hash code for this object.
no setterinherited
hideValue → bool
Whether the value is displayed or not
final
isError → bool
Whether this list tile is intended to display error widget.
final
isLoading → bool
Whether this list tile is intended to display loading stats.
final
isTwoLine → bool
Whether this list tile is intended to display two lines of text.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
A widget to display before the title.
final
loadingIndicator → Widget?
Widget used as loading indicator
final
loadingMessage → Widget?
Widget used as loading message
final
loadingText → String?
String text used as loading text
final
onTap → GestureTapCallback
Called when the user taps this list tile.
final
padding → EdgeInsetsGeometry?
The tile's internal padding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
If this tile is also enabled then icons and text are rendered with the same color.
final
title → Widget
The primary content of the list tile.
final
trailing → Widget?
A widget to display after the title.
final
value → Widget
The value of the selected option.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultLoadingIndicator → const Widget
Returns default loading indicator widget
defaultTrailing → const Widget
Returns default trailing widget